package router

import (
	"applet/app/cfg"
	"applet/app/hdl"
	"applet/app/hdl/comm"
	"applet/app/hdl/home_page"
	"applet/app/mw"
	_ "applet/docs"
	"github.com/gin-gonic/gin"
	swaggerFiles "github.com/swaggo/files"
	ginSwagger "github.com/swaggo/gin-swagger"
)

// 初始化路由
func Init() *gin.Engine {
	// debug, release, test 项目阶段
	mode := "release"
	if cfg.Debug {
		mode = "debug"
	}
	gin.SetMode(mode)
	//创建一个新的启动器
	r := gin.New()
	r.GET("/api/swagger/*any", func(c *gin.Context) {
		// r.Use(mw.SwagAuth())
		ginSwagger.DisablingWrapHandler(swaggerFiles.Handler, "SWAGGER")(c)
	})

	// 是否打印访问日志, 在非正式环境都打印
	if mode != "release" {
		r.Use(gin.Logger())
	}
	r.Use(gin.Recovery())

	r.GET("/favicon.ico", func(c *gin.Context) {
		c.Status(204)
	})
	r.NoRoute(func(c *gin.Context) {
		c.JSON(404, gin.H{"code": 404, "msg": "page not found", "data": []struct{}{}})
	})
	r.NoMethod(func(c *gin.Context) {
		c.JSON(405, gin.H{"code": 405, "msg": "method not allowed", "data": []struct{}{}})
	})
	r.Use(mw.Cors)
	route(r.Group("/api/v1"))
	return r
}

func route(r *gin.RouterGroup) {
	r.GET("/test", hdl.Demo)
	r.Any("/createSign", hdl.CreateSign)
	r.Any("/aesDecryptByECB", hdl.AesDecryptByECB)
	r.Use(mw.CheckSign)
	r.Any("/testCreateSign", hdl.TestCreateSign)
	r.POST("/register", hdl.Register)
	r.POST("/login", hdl.Login)
	r.Use(mw.Auth) // 以下接口需要JWT验证
	rComm(r.Group("/comm"))
	rHomePage := r.Group("/homePage")
	{
		rHomePage.GET("/index", home_page.HomePage)              // 主页
		rHomePage.GET("/adRule", home_page.HomePageWatchAdRule)  // 可以观看广告列表
		rHomePage.GET("/realTimePrice", home_page.RealTimePrice) // 实时数据
		rHomePage.GET("/isCanSignIn", home_page.IsCanSignIn)     // 是否可以观看广告
	}

}

func rComm(r *gin.RouterGroup) {
	r.GET("/getOssUrl", comm.GetOssUrl) // 获取阿里云上传PutObject所需的签名URL
}
